@@ -3,10 +3,14 @@ from webassets import Bundle
 all_css = Bundle(
     'bootstrap/css/bootstrap.css',
     'font-awesome/css/font-awesome.css',
+    'chosen/chosen.min.css',
     'esauth/css/sticky-footer-navbar.css',
+    'esauth/css/chosen-bootstrap.css',
+    'esauth/css/main.css',
 )
 
 all_js = Bundle(
     'jslibs/jquery-2.0.3.min.js',
     'bootstrap/js/bootstrap.min.js',
+    'chosen/chosen.jquery.min.js',
 )
